#!/bin/bash

session="photon"
make_dir=/home/vagrant/Hangar
work_dir=/home/vagrant/Hangar/networks/PhotonV3
cmd_mininet='bash -c "./run.sh"; p0h0 create_screen "p0h0"; p0h1 create_screen "p0h1"'
cmd_cli='python3 controlPlaneFiles.py; sleep 1; ./sendCoefficients.sh'
cmd_sender='sudo attach_screen p0h0; ./send.py --host_iface p0h0-eth1 192.0.0.3 --count 1000 --version 3'
cmd_receiver='sudo attach_screen p0h1; ./receive.py'


# turn on vm
vagrant up

#if session exists, kill it
tmux has-session -t $session 2>/dev/null
if [ $? == 0 ]; then
    tmux kill-session -t $session
fi

# create session
tmux new -d -s $session

#create 4 panes in inner, 1 for mininet, one for bmv2 cli, and one each for sender and receiver 
tmux send-keys -t $session \; split-window -v \; split-window -h \; select-pane -t 0 \; split-window -h \;

#make everyone go into hangar 
tmux send-keys -t $session.0 "sshpass -p vagrant vagrant ssh" Enter \;
tmux send-keys -t $session.1 "sshpass -p vagrant vagrant ssh" Enter \;
tmux send-keys -t $session.2 "sshpass -p vagrant vagrant ssh" Enter \;
tmux send-keys -t $session.3 "sshpass -p vagrant vagrant ssh" Enter \;

#compile PhotonV3.p4
tmux send-keys -t $session.0 "cd $made_dir; make clean; make" Enter \;

# get into working directory
tmux send-keys -t $session.0 "cd $work_dir" Enter \;
tmux send-keys -t $session.1 "cd $work_dir" Enter \;
tmux send-keys -t $session.2 "cd $work_dir" Enter \;
tmux send-keys -t $session.3 "cd $work_dir" Enter \;

#set up screens, set up mirroring session for 'for looping', and populate taylor polynomial registers
tmux send-keys -t $session.0 "$cmd_mininet" Enter \;
tmux send-keys -t $session.1 "$cmd_cli" 
tmux send-keys -t $session.2 "$cmd_sender"
tmux send-keys -t $session.3 "$cmd_receiver"

# attach and run session
# comment out the following line, and uncomment the 4th next line to do recording
#tmux a -t $session

#attach and record session
asciinema rec -c "tmux a -t $session"

#pull hangargames output
#sshpass -p vagrant vagrant scp default:$work_dir/hangargames_output .
